@@ -3,6 +3,7 @@ import re
 import sys
 import copy
 import time
+import platform
 import threading
 import importlib
 import traceback
@@ -20,6 +21,7 @@ import allure
 import pytest
 from box import Box
 import simplejson as json
+
 import config.settings as settings
 from framework.exit_code import ExitCode
 from framework.db.mysql_db import MysqlDB
@@ -522,14 +524,14 @@ def pytest_terminal_summary(terminalreporter, exitstatus, config):
     terminalreporter.write(f"跳过用例数: {skipped}\n", yellow=True, bold=True)
     terminalreporter.write(f"用例通过率: {pass_rate}%\n", green=True, bold=True)
     terminalreporter.write("====================================\n", blue=True, bold=True)
-    CONTEXT.set("summary", {
-        "total": total,
-        "passed": passed,
-        "failed": failed,
-        "skipped": skipped,
-        "pass_rate": pass_rate
-    })
-    # LarkUtil(settings.LARK_WEBHOOK).send_test_report(total=total, passed=passed, failed=failed, skipped=skipped)
+    if "linux" in platform.platform().lower():
+        LarkUtil(settings.LARK_WEBHOOK).send_test_report(
+            total=total,
+            passed=passed,
+            failed=failed,
+            skipped=skipped,
+            report_url=os.environ.get("ALLURE_REPORT_URL")
+        )
 
 
 def pytest_exception_interact(node, call, report):
