@@ -1,6 +1,7 @@
-from enum import Enum
+from enum import Enum, unique
 
 
+@unique
 class ExitCode(Enum):
     ENV_NOT_EXIST = 10001  # 测试环境不存在
     APP_NOT_EXIST = 10002  # 测试系统不存在
@@ -16,5 +17,8 @@ class ExitCode(Enum):
     MISSING_ASSERTIONS = 10012  # 缺少断言
     APP_OR_ACCOUNT_NOT_EXIST = 10013  # 账号角色不存在
     MORE_THAN_ONE_TEST_SUITE_SETUP = 10014  # test_suite_setup标签只能配置一个
-    LOAD_DATABASE_INFO_ERROR = 10015
-    GLOBAL_SCRIPT_ERROR = 10016
+    LOAD_DATABASE_INFO_ERROR = 10015  # 连接数据库异常
+    GLOBAL_SCRIPT_ERROR = 10016  # 脚本定义错误
+    SCENARIO_FORMAT_ERROR = 10017  # scenario格式错误
+    NONSUPPORT_RUN_MODE = 10018  # 不支持的运行方式
+    NON_CASE = 10019  # 不支持的运行方式
